==> lift-webkit-0.7.jar: toserve/jlift-min.js <==
(function(){window.lift$={buildIndex:function(on,indexName){on[indexName]={};
var index=on[indexName];
var x=0;
for(x=2;
x<arguments.length;
x++){var arg=arguments[x];
var keyField=arg[1];
var table=arg[0];
var ta=on[table];
var y=0;
for(y=0;
y<ta.length;
y++){var item=ta[y];
var id=item[keyField];
if(id){index[id]=item
}}}},foreach:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}for(var x=0;
x<array.length;
x++){realFunc(array[x])
}},fold:function(array,initVal,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1, p2) {return "+func+";}")
}lift$.foreach(array,function(e){initVal=realFunc(initVal,e)
});
return initVal
},filter:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){if(realFunc(e)){ret.push(e)
}});
return ret
},alt:function(val,func,altVal){if(val==false||val==null){if(altVal.apply){return altVal()
}return altVal
}else{if(lift$.isArray(val)){return lift$.map(val,func)
}else{var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}return realFunc(val)
}}},map:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){ret.push(realFunc(e))
});
return ret
},flatMap:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){lift$.foreach(realFunc(e),function(v){ret.push(v)
})
});
return ret
},sort:function(array){var func=null;
if(arguments.length>1){func=arguments[1]
}var realArray=[].concat(array);
if(func==null){return realArray.sort()
}else{var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1, p2) {return "+func+";}")
}return realArray.sort(realFunc)
}},take:function(array,num){var ret=[];
for(var x=0;
x<array.length&&x<num;
x++){ret.push(array[x])
}return ret
},magicUpdate:function(holder,field,idField,toUpdate){var f=function(array,item){var na=lift$.filter(array,function(i){return i[idField]!=item[idField]
});
na.push(item);
return na
};
var ta=holder[field];
if(lift$.isArray(toUpdate)){lift$.foreach(toUpdate,function(i){ta=f(ta,i)
});
holder[field]=ta
}else{holder[field]=f(ta,toUpdate)
}},isArray:function(obj){if(obj.constructor.toString().indexOf("Array")==-1){return false
}else{return true
}},randomId:function(){var ret="i";
for(var x=0;
x<10;
x++){ret=ret+(Math.floor(Math.random()*1000))
}return ret
},swappable:function(visible,hidden){if(visible==null){visible=""
}if(hidden==null){hidden=""
}if(visible.nodeType==null){visible=document.createTextNode(visible.toString())
}if(visible.nodeType!=1){var tmp=document.createElement("span");
tmp.appendChild(visible);
visible=tmp
}if(hidden.nodeType==null){hidden=document.createTextNode(hidden.toString())
}if(hidden.nodeType!=1){var tmp=document.createElement("span");
tmp.appendChild(hidden);
hidden=tmp
}visible.onclick=function(){jQuery(visible).hide();
jQuery(hidden).show();
jQuery(hidden).focus();
jQuery(hidden).children(":input").focus();
return false
};
hidden.style.display="none";
var onblur=function(){jQuery(visible).show();
jQuery(hidden).hide()
};
jQuery(hidden).blur(onblur);
jQuery(hidden).children().blur(onblur);
var df=document.createDocumentFragment();
df.appendChild(visible);
df.appendChild(hidden);
return df
}}
})();

==> lift-webkit-1.0.3.jar: toserve/jlift-min.js <==
(function(){window.lift$={buildIndex:function(on,indexName){on[indexName]={};
var index=on[indexName];
var x=0;
for(x=2;
x<arguments.length;
x++){var arg=arguments[x];
var keyField=arg[1];
var table=arg[0];
var ta=on[table];
var y=0;
for(y=0;
y<ta.length;
y++){var item=ta[y];
var id=item[keyField];
if(id){index[id]=item
}}}},foreach:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}for(var x=0;
x<array.length;
x++){realFunc(array[x])
}},fold:function(array,initVal,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1, p2) {return "+func+";}")
}lift$.foreach(array,function(e){initVal=realFunc(initVal,e)
});
return initVal
},filter:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){if(realFunc(e)){ret.push(e)
}});
return ret
},alt:function(val,func,altVal){if(val==false||val==null){if(altVal.apply){return altVal()
}return altVal
}else{if(lift$.isArray(val)){return lift$.map(val,func)
}else{var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}return realFunc(val)
}}},map:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){ret.push(realFunc(e))
});
return ret
},flatMap:function(array,func){var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1) {return "+func+";}")
}var ret=[];
lift$.foreach(array,function(e){lift$.foreach(realFunc(e),function(v){ret.push(v)
})
});
return ret
},sort:function(array){var func=null;
if(arguments.length>1){func=arguments[1]
}var realArray=[].concat(array);
if(func==null){return realArray.sort()
}else{var realFunc=func;
if(func.apply==null){eval("realFunc = function(p1, p2) {return "+func+";}")
}return realArray.sort(realFunc)
}},take:function(array,num){var ret=[];
for(var x=0;
x<array.length&&x<num;
x++){ret.push(array[x])
}return ret
},magicUpdate:function(holder,field,idField,toUpdate){var f=function(array,item){var na=lift$.filter(array,function(i){return i[idField]!=item[idField]
});
na.push(item);
return na
};
var ta=holder[field];
if(lift$.isArray(toUpdate)){lift$.foreach(toUpdate,function(i){ta=f(ta,i)
});
holder[field]=ta
}else{holder[field]=f(ta,toUpdate)
}},isArray:function(obj){if(obj.constructor.toString().indexOf("Array")==-1){return false
}else{return true
}},randomId:function(){var ret="i";
for(var x=0;
x<10;
x++){ret=ret+(Math.floor(Math.random()*1000))
}return ret
},swappable:function(visible,hidden){if(visible==null){visible=""
}if(hidden==null){hidden=""
}if(visible.nodeType==null){visible=document.createTextNode(visible.toString())
}if(visible.nodeType!=1){var tmp=document.createElement("span");
tmp.appendChild(visible);
visible=tmp
}if(hidden.nodeType==null){hidden=document.createTextNode(hidden.toString())
}if(hidden.nodeType!=1){var tmp=document.createElement("span");
tmp.appendChild(hidden);
hidden=tmp
}visible.onclick=function(){jQuery(visible).hide();
jQuery(hidden).show();
jQuery(hidden).focus();
jQuery(hidden).children(":input").focus();
return false
};
hidden.style.display="none";
var onblur=function(){jQuery(visible).show();
jQuery(hidden).hide()
};
jQuery(hidden).blur(onblur);
jQuery(hidden).children().blur(onblur);
var df=document.createDocumentFragment();
df.appendChild(visible);
df.appendChild(hidden);
return df
},formToJSON:function(formId){qs=this.param(jQuery("#"+formId).serializeArray());
parts=qs.split("&");
json="";
for(i=0;
i<parts.length;
i++){nvp=parts[i].split("=");
json+=(i>0)?",":"";
json+='"'+nvp[0]+'": "'+nvp[1]+'"'
}return JSON.parse("{"+json+"}")
},param:function(a){var s=[];
if(a.constructor==Array||a.jquery){jQuery.each(a,function(){s.push(this.name+"="+this.value)
})
}else{for(var j in a){if(a[j]&&a[j].constructor==Array){jQuery.each(a[j],function(){s.push(j+"="+this)
})
}else{s.push(j+"="+jQuery.isFunction(a[j])?a[j]():a[j])
}}}return s.join("&")
}}
})();
